@@ -62,7 +62,7 @@ class RPickFigure(RFFigure):
         idx = np.argsort(self.baz)
         self.baz = self.baz[idx]
         self.rrf = [self.rrf[i] for i in idx]
-        self.gcarc = [self.rrf[i].stats.sac.gcarc for i in idx]
+        self.gcarc = [self.rrf[i].stats.sac.gcarc for i in range(self.evt_num)]
         self.filenames = [self.filenames[i] for i in idx]
 
     def set_figure(self):
